@@ -34,6 +34,12 @@ outlier <- function(x, full = FALSE){
   
   ol.type <- substr(ol, start = 1, stop = 2)
   ol.time <- substr(ol, start = 3, stop = nchar(ol))
+
+  # if a range ("2001.3-2004.3"), only use the start date ("2001.3")
+  is.range <- grepl("-", ol.time, fixed = TRUE)
+  if (any(is.range)){
+    ol.time[is.range] <- gsub("-.+$", "", ol.time[is.range])
+  }
   
   if (frequency(z) == 12){
     ol.time.R <- lapply(strsplit(ol.time, "\\."), 
