@@ -27,6 +27,10 @@
 #' }
 #' @param object      an object of class \code{"seas"}, usually, a result of a 
 #'                    call to \code{\link{seas}}.
+#' @param stats  (experimental) character vector, additional stat to be shown in the \code{summary} output.
+#'   function. For a list of all possible values, see the \code{\link{udg}} 
+#'   function. If a value is not present, it will be ignored. Values can be 
+#'   specified via \code{options}. See examples.
 #' @param x           an object of class \code{"summary.seas"}, usually, a result 
 #'                    of a call to \code{summary.seas}.
 #' @param digits      the number of significant digits to use when printing.
@@ -50,10 +54,23 @@
 #' \dontrun{
 #' m <- seas(AirPassengers)
 #' summary(m)  
+#' 
+#' ### user defined stats from the udg function 
+#' # (experimental, see ?udg)
+#' 
+#' # also show some M quality statistics for X11 in summary
+#' options(seas.stats = c("f3.m01", "f3.m02", "f3.m03", "f3.m04"))
+#' summary(seas(AirPassengers, x11 = ""))
+#' 
+#' # this does not affect the SEATS output
+#' summary(seas(AirPassengers))
+#' 
+#' # reset to default
+#' options(seas.stats = NULL)
 #' }
 #' @method summary seas
 #' @export
-summary.seas <- function(object, ...){
+summary.seas <- function(object, stats = getOption("seas.stats"), ...){
   # build output on top of the input
   z <- object
   
@@ -72,9 +89,14 @@ summary.seas <- function(object, ...){
   }
   
   z$resid <- residuals(object)
-  z$qs <- qs(object)
   z$transform.function <- transformfunction(object)
-  
+  z$qsv <- qs(object)[c('qssadj'), ]
+  z$stats <- stats
+
+  z$nobs <- nobs(object)
+  z$aicc <- unname(udg(object, "aicc"))
+  z$bic <- BIC(object)
+
   class(z) <- "summary.seas"
   z
 }
@@ -85,8 +107,8 @@ summary.seas <- function(object, ...){
 #' @export
 #' @rdname summary.seas
 print.summary.seas <- function (x, digits = max(3, getOption("digits") - 3), 
-                              signif.stars = getOption("show.signif.stars"), ...) {
-  
+                                signif.stars = getOption("show.signif.stars"), ...) {
+
   cat("\nCall:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"), "\n",
       sep = "")
   
@@ -109,14 +131,13 @@ print.summary.seas <- function (x, digits = max(3, getOption("digits") - 3),
   }
   
   cat("  ARIMA:", x$model$arima$model)
-
-  cat("  Obs.:", formatC(x$lks['nobs'], format = "d"))
+  cat("  Obs.:", formatC(x$nobs, format = "d"))
   cat("  Transform:", x$transform.function)
-  cat("\nAICc:", formatC(x$lks['Aicc'], digits = digits))
-  cat(", BIC:", formatC(x$lks['bic'], digits = digits))
+  cat("\nAICc:", formatC(x$aicc, digits = digits))
+  cat(", BIC:", formatC(x$bic, digits = digits))
 
   # QS Test
-  qsv <- qs(x)[c('qssadj'), ]
+  qsv <- x$qsv
   qsstars <- symnum(as.numeric(qsv['p-val']), 
                     corr = FALSE, na = FALSE, legend = FALSE,
                     cutpoints = c(0, 0.001, 0.01, 0.05, 0.1, 1), 
@@ -141,8 +162,31 @@ print.summary.seas <- function (x, digits = max(3, getOption("digits") - 3),
                       symbols = c("***", "**", "*", ".", " "))
     cat(" Shapiro (normality):", formatC(swtest$statistic, digits = digits), swstars)
   }
+  
+  if (!is.null(x$stats)){
+    x1 <- x; class(x1) <- "seas"  # reclassify, so udg() can be used on it
+    uu0 <- udg(x1, x1$stats, fail = FALSE, simplify = FALSE)
+      if (length(uu0) > 0){
+        # format numeric
+        cformat <- function(x){
+          if (inherits(x, "numeric")) {
+            prettyNum(x, digits = digits)
+          } else {
+            x
+          }
+        }
+
+        # make multi element vetors single element, to char vector
+        uu0 <- sapply(uu0, function(e) paste(cformat(e), collapse = ", "))
+
+        stats <- paste0(names(uu0), ": ", uu0, " ")
+        cat("\n")
+        cat(stats, fill = 0.8 * getOption("width"))
+      }
+  }
+
   if (!is.null(x$err)){
-    cat("\n")
+    # cat("\n")
     print(x$err)
   }
   cat("\n")
